@@ -1,6 +1,11 @@
+from typing import List
 import numpy as np
 
+from dataclasses import dataclass
+from sectionproperties.pre.pre import Material
 
+
+@dataclass
 class Tri6:
     """Class for a six noded quadratic triangular element.
 
@@ -27,19 +32,20 @@ class Tri6:
     :vartype material: :class:`~sectionproperties.pre.pre.Material`
     """
 
-    def __init__(self, el_id, coords, node_ids, material):
-        """Inits the Tri6 class."""
+    el_id: int
+    coords: np.ndarray
+    node_ids: List[int]
+    material: Material
 
-        self.el_id = el_id
-        self.coords = coords
-        self.node_ids = node_ids
-        self.material = material
+    def __repr__(self):
+        rep = f"el_id: {self.el_id}\ncoords: {self.coords}\nnode_ids: {self.node_ids}\nmaterial: {self.material}"
+        return rep
 
     def geometric_properties(self):
         """Calculates the geometric properties for the current finite element.
 
         :return: Tuple containing the geometric properties and the elastic and shear moduli of the
-            element: *(area, qx, qy, ixx, iyy, ixy, e, g)*
+            element: *(area, qx, qy, ixx, iyy, ixy, e, g, rho)*
         :rtype: tuple(float)
         """
 
@@ -58,6 +64,8 @@ class Tri6:
         for gp in gps:
             # determine shape function, shape function derivative and jacobian
             (N, _, j) = shape_function(self.coords, gp)
+            # log.log(level=logging.DEBUG, msg=f"N: {N}\nj: {j}")
+            # log.log(level=logging.DEBUG, msg=f"self.coords: {self.coords}\n")
 
             area += gp[0] * j
             qx += gp[0] * np.dot(N, np.transpose(self.coords[1, :])) * j
@@ -65,12 +73,22 @@ class Tri6:
             ixx += gp[0] * np.dot(N, np.transpose(self.coords[1, :])) ** 2 * j
             iyy += gp[0] * np.dot(N, np.transpose(self.coords[0, :])) ** 2 * j
             ixy += (
-                gp[0] * np.dot(N, np.transpose(self.coords[1, :])) * np.dot(
-                    N, np.transpose(self.coords[0, :])) * j
+                gp[0]
+                * np.dot(N, np.transpose(self.coords[1, :]))
+                * np.dot(N, np.transpose(self.coords[0, :]))
+                * j
             )
 
         return (
-            area, qx, qy, ixx, iyy, ixy, self.material.elastic_modulus, self.material.shear_modulus
+            area,
+            qx,
+            qy,
+            ixx,
+            iyy,
+            ixy,
+            self.material.elastic_modulus,
+            self.material.shear_modulus,
+            self.material.density,
         )
 
     def torsion_properties(self):
@@ -97,10 +115,14 @@ class Tri6:
             Ny = np.dot(N, np.transpose(self.coords[1, :]))
 
             # calculated modulus weighted stiffness matrix and load vector
-            k_el += gp[0] * np.dot(np.transpose(B), B) * j * (self.material.elastic_modulus)
+            k_el += (
+                gp[0] * np.dot(np.transpose(B), B) * j * (self.material.elastic_modulus)
+            )
             f_el += (
-                gp[0] * np.dot(np.transpose(B), np.transpose(np.array([Ny, -Nx]))) *
-                j * self.material.elastic_modulus
+                gp[0]
+                * np.dot(np.transpose(B), np.transpose(np.array([Ny, -Nx])))
+                * j
+                * self.material.elastic_modulus
             )
 
         return (k_el, f_el)
@@ -141,14 +163,26 @@ class Tri6:
             h2 = -iyy * r - ixy * q
 
             f_psi += (
-                gp[0] * (nu / 2 * np.transpose(np.transpose(B).dot(np.array([[d1], [d2]])))[0] +
-                         2 * (1 + nu) * np.transpose(N) * (ixx * Nx - ixy * Ny)) * j *
-                self.material.elastic_modulus
+                gp[0]
+                * (
+                    nu
+                    / 2
+                    * np.transpose(np.transpose(B).dot(np.array([[d1], [d2]])))[0]
+                    + 2 * (1 + nu) * np.transpose(N) * (ixx * Nx - ixy * Ny)
+                )
+                * j
+                * self.material.elastic_modulus
             )
             f_phi += (
-                gp[0] * (nu / 2 * np.transpose(np.transpose(B).dot(np.array([[h1], [h2]])))[0] +
-                         2 * (1 + nu) * np.transpose(N) * (iyy * Ny - ixy * Nx)) * j *
-                self.material.elastic_modulus
+                gp[0]
+                * (
+                    nu
+                    / 2
+                    * np.transpose(np.transpose(B).dot(np.array([[h1], [h2]])))[0]
+                    + 2 * (1 + nu) * np.transpose(N) * (iyy * Ny - ixy * Nx)
+                )
+                * j
+                * self.material.elastic_modulus
             )
 
         return (f_psi, f_phi)
@@ -189,12 +223,18 @@ class Tri6:
             Nomega = np.dot(N, np.transpose(omega))
 
             sc_xint += (
-                gp[0] * (iyy * Nx + ixy * Ny) * (Nx ** 2 + Ny ** 2) *
-                j * self.material.elastic_modulus
+                gp[0]
+                * (iyy * Nx + ixy * Ny)
+                * (Nx ** 2 + Ny ** 2)
+                * j
+                * self.material.elastic_modulus
             )
             sc_yint += (
-                gp[0] * (ixx * Ny + ixy * Nx) * (Nx ** 2 + Ny ** 2) *
-                j * self.material.elastic_modulus
+                gp[0]
+                * (ixx * Ny + ixy * Nx)
+                * (Nx ** 2 + Ny ** 2)
+                * j
+                * self.material.elastic_modulus
             )
             q_omega += gp[0] * Nomega * j * self.material.elastic_modulus
             i_omega += gp[0] * Nomega ** 2 * j * self.material.elastic_modulus
@@ -244,26 +284,35 @@ class Tri6:
             h2 = -iyy * r - ixy * q
 
             kappa_x += (
-                gp[0] * (psi_shear.dot(np.transpose(B)) - nu / 2 * np.array([d1, d2])).dot(
-                    B.dot(psi_shear) - nu / 2 * np.array([d1, d2])) * j *
-                self.material.elastic_modulus
+                gp[0]
+                * (psi_shear.dot(np.transpose(B)) - nu / 2 * np.array([d1, d2])).dot(
+                    B.dot(psi_shear) - nu / 2 * np.array([d1, d2])
+                )
+                * j
+                * self.material.elastic_modulus
             )
             kappa_y += (
-                gp[0] * (phi_shear.dot(np.transpose(B)) - nu / 2 * np.array([h1, h2])).dot(
-                    B.dot(phi_shear) - nu / 2 * np.array([h1, h2])) * j *
-                self.material.elastic_modulus
+                gp[0]
+                * (phi_shear.dot(np.transpose(B)) - nu / 2 * np.array([h1, h2])).dot(
+                    B.dot(phi_shear) - nu / 2 * np.array([h1, h2])
+                )
+                * j
+                * self.material.elastic_modulus
             )
             kappa_xy += (
-                gp[0] * (psi_shear.dot(np.transpose(B)) - nu / 2 * np.array([d1, d2])).dot(
-                    B.dot(phi_shear) - nu / 2 * np.array([h1, h2])) * j *
-                self.material.elastic_modulus
+                gp[0]
+                * (psi_shear.dot(np.transpose(B)) - nu / 2 * np.array([d1, d2])).dot(
+                    B.dot(phi_shear) - nu / 2 * np.array([h1, h2])
+                )
+                * j
+                * self.material.elastic_modulus
             )
 
         return (kappa_x, kappa_y, kappa_xy)
 
     def monosymmetry_integrals(self, phi):
         """Calculates the integrals used to evaluate the monosymmetry constant about both global
-        axes and both prinicipal axes.
+        axes and both principal axes.
 
         :param float phi: Principal bending axis angle
 
@@ -293,65 +342,59 @@ class Tri6:
             (Nx_11, Ny_22) = principal_coordinate(phi, Nx, Ny)
 
             # weight the monosymmetry integrals by the section elastic modulus
-            int_x += gp[0] * (Nx * Nx * Ny + Ny * Ny * Ny) * j * self.material.elastic_modulus
-            int_y += gp[0] * (Ny * Ny * Nx + Nx * Nx * Nx) * j * self.material.elastic_modulus
+            int_x += (
+                gp[0]
+                * (Nx * Nx * Ny + Ny * Ny * Ny)
+                * j
+                * self.material.elastic_modulus
+            )
+            int_y += (
+                gp[0]
+                * (Ny * Ny * Nx + Nx * Nx * Nx)
+                * j
+                * self.material.elastic_modulus
+            )
             int_11 += (
-                gp[0] * (Nx_11 * Nx_11 * Ny_22 + Ny_22 * Ny_22 * Ny_22) * j *
-                self.material.elastic_modulus
+                gp[0]
+                * (Nx_11 * Nx_11 * Ny_22 + Ny_22 * Ny_22 * Ny_22)
+                * j
+                * self.material.elastic_modulus
             )
             int_22 += (
-                gp[0] * (Ny_22 * Ny_22 * Nx_11 + Nx_11 * Nx_11 * Nx_11) * j *
-                self.material.elastic_modulus
+                gp[0]
+                * (Ny_22 * Ny_22 * Nx_11 + Nx_11 * Nx_11 * Nx_11)
+                * j
+                * self.material.elastic_modulus
             )
 
         return (int_x, int_y, int_11, int_22)
 
-    def plastic_properties(self, u, p):
-        """Calculates total force resisted by the element when subjected to a stress equal to the
-        yield strength. Also returns the modulus weighted area and first moments of area, and
-        determines whether or not the element is above or below the line defined by the unit
-        vector *u* and point *p*.
-
-        :param u: Unit vector in the direction of the line
-        :type u: :class:`numpy.ndarray`
-        :param p: Point on the line
-        :type p: :class:`numpy.ndarray`
-
-        :return: Element force *(force)*, modulus weighted area properties *(ea, e.qx, e.qy)* and
-            whether or not the element is above the line
-        :rtype: tuple(float, float, float, float, bool)
-        """
-
-        # initialise geometric properties
-        e = self.material.elastic_modulus
-        area = 0
-        qx = 0
-        qy = 0
-        force = 0
-
-        # Gauss points for 3 point Gaussian integration
-        gps = gauss_points(3)
-
-        # loop through each Gauss point
-        for gp in gps:
-            # determine shape function, shape function derivative and jacobian
-            (N, _, j) = shape_function(self.coords, gp)
-
-            area += gp[0] * j
-            qx += gp[0] * np.dot(N, np.transpose(self.coords[1, :])) * j
-            qy += gp[0] * np.dot(N, np.transpose(self.coords[0, :])) * j
-            force += gp[0] * j * self.material.yield_strength
-
-        # calculate element centroid
-        (cx, cy) = (qy / area, qx / area)
-
-        # determine if the element is above the line p + u
-        is_above = point_above_line(u, p[0], p[1], cx, cy)
-
-        return (force, area * e, qx * e, qy * e, is_above)
-
-    def element_stress(self, N, Mxx, Myy, M11, M22, Mzz, Vx, Vy, ea, cx, cy, ixx, iyy, ixy, i11,
-                       i22, phi, j, nu, omega, psi_shear, phi_shear, Delta_s):
+    def element_stress(
+        self,
+        N,
+        Mxx,
+        Myy,
+        M11,
+        M22,
+        Mzz,
+        Vx,
+        Vy,
+        ea,
+        cx,
+        cy,
+        ixx,
+        iyy,
+        ixy,
+        i11,
+        i22,
+        phi,
+        j,
+        nu,
+        omega,
+        psi_shear,
+        phi_shear,
+        Delta_s,
+    ):
         """Calculates the stress within an element resulting from a specified loading. Also returns
         the shape function weights.
 
@@ -431,32 +474,39 @@ class Tri6:
             h2 = -iyy * r - ixy * q
 
             # calculate element stresses
-            sig_zz_mxx_gp[i, :] = (
-                self.material.elastic_modulus * (-(ixy * Mxx) / (ixx * iyy - ixy ** 2) * Nx + (
-                    iyy * Mxx) / (ixx * iyy - ixy ** 2) * Ny)
+            sig_zz_mxx_gp[i, :] = self.material.elastic_modulus * (
+                -(ixy * Mxx) / (ixx * iyy - ixy ** 2) * Nx
+                + (iyy * Mxx) / (ixx * iyy - ixy ** 2) * Ny
             )
-            sig_zz_myy_gp[i, :] = (
-                self.material.elastic_modulus * (-(ixx * Myy) / (ixx * iyy - ixy ** 2) * Nx + (
-                    ixy * Myy) / (ixx * iyy - ixy ** 2) * Ny)
+            sig_zz_myy_gp[i, :] = self.material.elastic_modulus * (
+                -(ixx * Myy) / (ixx * iyy - ixy ** 2) * Nx
+                + (ixy * Myy) / (ixx * iyy - ixy ** 2) * Ny
             )
             sig_zz_m11_gp[i, :] = self.material.elastic_modulus * M11 / i11 * Ny_22
             sig_zz_m22_gp[i, :] = self.material.elastic_modulus * -M22 / i22 * Nx_11
 
             if Mzz != 0:
                 sig_zxy_mzz_gp[i, :] = (
-                    self.material.elastic_modulus * Mzz / j * (B.dot(omega) - np.array([Ny, -Nx]))
+                    self.material.elastic_modulus
+                    * Mzz
+                    / j
+                    * (B.dot(omega) - np.array([Ny, -Nx]))
                 )
 
             if Vx != 0:
                 sig_zxy_vx_gp[i, :] = (
-                    self.material.elastic_modulus * Vx / Delta_s * (
-                        B.dot(psi_shear) - nu / 2 * np.array([d1, d2]))
+                    self.material.elastic_modulus
+                    * Vx
+                    / Delta_s
+                    * (B.dot(psi_shear) - nu / 2 * np.array([d1, d2]))
                 )
 
             if Vy != 0:
                 sig_zxy_vy_gp[i, :] = (
-                    self.material.elastic_modulus * Vy / Delta_s * (
-                        B.dot(phi_shear) - nu / 2 * np.array([h1, h2]))
+                    self.material.elastic_modulus
+                    * Vy
+                    / Delta_s
+                    * (B.dot(phi_shear) - nu / 2 * np.array([h1, h2]))
                 )
 
         # extrapolate results to nodes
@@ -471,8 +521,20 @@ class Tri6:
         sig_zx_vy = extrapolate_to_nodes(sig_zxy_vy_gp[:, 0])
         sig_zy_vy = extrapolate_to_nodes(sig_zxy_vy_gp[:, 1])
 
-        return (sig_zz_n, sig_zz_mxx, sig_zz_myy, sig_zz_m11, sig_zz_m22, sig_zx_mzz, sig_zy_mzz,
-                sig_zx_vx, sig_zy_vx, sig_zx_vy, sig_zy_vy, gps[:, 0])
+        return (
+            sig_zz_n,
+            sig_zz_mxx,
+            sig_zz_myy,
+            sig_zz_m11,
+            sig_zz_m22,
+            sig_zx_mzz,
+            sig_zy_mzz,
+            sig_zx_vx,
+            sig_zy_vx,
+            sig_zx_vy,
+            sig_zy_vy,
+            gps[:, 0],
+        )
 
     def point_within_element(self, pt):
         """Determines whether a point lies within the current element.
@@ -495,13 +557,11 @@ class Tri6:
         y3 = self.coords[1][2]
 
         # compute variables alpha, beta and gamma
-        alpha = (
-            ((y2 - y3) * (px - x3) + (x3 - x2) * (py - y3)) /
-            ((y2 - y3) * (x1 - x3) + (x3 - x2) * (y1 - y3))
+        alpha = ((y2 - y3) * (px - x3) + (x3 - x2) * (py - y3)) / (
+            (y2 - y3) * (x1 - x3) + (x3 - x2) * (y1 - y3)
         )
-        beta = (
-            ((y3 - y1) * (px - x3) + (x1 - x3) * (py - y3)) /
-            ((y2 - y3) * (x1 - x3) + (x3 - x2) * (y1 - y3))
+        beta = ((y3 - y1) * (px - x3) + (x1 - x3) * (py - y3)) / (
+            (y2 - y3) * (x1 - x3) + (x3 - x2) * (y1 - y3)
         )
         gamma = 1.0 - alpha - beta
 
@@ -528,11 +588,13 @@ def gauss_points(n):
 
     elif n == 3:
         # three point gaussian integration
-        return np.array([
-            [1.0 / 3, 2.0 / 3, 1.0 / 6, 1.0 / 6],
-            [1.0 / 3, 1.0 / 6, 2.0 / 3, 1.0 / 6],
-            [1.0 / 3, 1.0 / 6, 1.0 / 6, 2.0 / 3]
-        ])
+        return np.array(
+            [
+                [1.0 / 3, 2.0 / 3, 1.0 / 6, 1.0 / 6],
+                [1.0 / 3, 1.0 / 6, 2.0 / 3, 1.0 / 6],
+                [1.0 / 3, 1.0 / 6, 1.0 / 6, 2.0 / 3],
+            ]
+        )
     elif n == 6:
         # six point gaussian integration
         g1 = 1.0 / 18 * (8 - np.sqrt(10) + np.sqrt(38 - 44 * np.sqrt(2.0 / 5)))
@@ -540,14 +602,16 @@ def gauss_points(n):
         w1 = (620 + np.sqrt(213125 - 53320 * np.sqrt(10))) / 3720
         w2 = (620 - np.sqrt(213125 - 53320 * np.sqrt(10))) / 3720
 
-        return np.array([
-            [w2, 1 - 2 * g2, g2, g2],
-            [w2, g2, 1 - 2 * g2, g2],
-            [w2, g2, g2, 1 - 2 * g2],
-            [w1, g1, g1, 1 - 2 * g1],
-            [w1, 1 - 2 * g1, g1, g1],
-            [w1, g1, 1 - 2 * g1, g1]
-        ])
+        return np.array(
+            [
+                [w2, 1 - 2 * g2, g2, g2],
+                [w2, g2, 1 - 2 * g2, g2],
+                [w2, g2, g2, 1 - 2 * g2],
+                [w1, g1, g1, 1 - 2 * g1],
+                [w1, 1 - 2 * g1, g1, g1],
+                [w1, g1, 1 - 2 * g1, g1],
+            ]
+        )
 
 
 def shape_function(coords, gauss_point):
@@ -570,21 +634,25 @@ def shape_function(coords, gauss_point):
     zeta = gauss_point[3]
 
     # value of the shape functions
-    N = np.array([
-        eta * (2 * eta - 1),
-        xi * (2 * xi - 1),
-        zeta * (2 * zeta - 1),
-        4 * eta * xi,
-        4 * xi * zeta,
-        4 * eta * zeta
-    ])
+    N = np.array(
+        [
+            eta * (2 * eta - 1),
+            xi * (2 * xi - 1),
+            zeta * (2 * zeta - 1),
+            4 * eta * xi,
+            4 * xi * zeta,
+            4 * eta * zeta,
+        ]
+    )
 
     # derivatives of the shape functions wrt the isoparametric co-ordinates
-    B_iso = np.array([
-        [4 * eta - 1, 0, 0, 4 * xi, 0, 4 * zeta],
-        [0, 4 * xi - 1, 0, 4 * eta, 4 * zeta, 0],
-        [0, 0, 4 * zeta - 1, 0, 4 * xi, 4 * eta]
-    ])
+    B_iso = np.array(
+        [
+            [4 * eta - 1, 0, 0, 4 * xi, 0, 4 * zeta],
+            [0, 4 * xi - 1, 0, 4 * eta, 4 * zeta, 0],
+            [0, 0, 4 * zeta - 1, 0, 4 * xi, 4 * eta],
+        ]
+    )
 
     # form Jacobian matrix
     J_upper = np.array([[1, 1, 1]])
@@ -596,7 +664,7 @@ def shape_function(coords, gauss_point):
 
     # if the area of the element is not zero
     if j != 0:
-        # cacluate the P matrix
+        # calculate the P matrix
         P = np.dot(np.linalg.inv(J), np.array([[0, 0], [1, 0], [0, 1]]))
 
         # calculate the B matrix in terms of cartesian co-ordinates
@@ -608,7 +676,7 @@ def shape_function(coords, gauss_point):
 
 
 def extrapolate_to_nodes(w):
-    """Extrapolates results at six Gauss points to the six noes of a quadratic triangular element.
+    """Extrapolates results at six Gauss points to the six nodes of a quadratic triangular element.
 
     :param w: Result at the six Gauss points [1 x 6]
     :type w: :class:`numpy.ndarray`
@@ -616,20 +684,58 @@ def extrapolate_to_nodes(w):
     :rtype: :class:`numpy.ndarray`
     """
 
-    H_inv = np.array([
-        [1.87365927351160,	0.138559587411935, 0.138559587411935,
-         -0.638559587411936, 0.126340726488397, -0.638559587411935],
-        [0.138559587411935, 1.87365927351160, 0.138559587411935,
-         -0.638559587411935, -0.638559587411935, 0.126340726488397],
-        [0.138559587411935, 0.138559587411935, 1.87365927351160,
-         0.126340726488396, -0.638559587411935, -0.638559587411935],
-        [0.0749010751157440, 0.0749010751157440, 0.180053080734478,
-         1.36051633430762,	-0.345185782636792, -0.345185782636792],
-        [0.180053080734478, 0.0749010751157440, 0.0749010751157440,
-         -0.345185782636792, 1.36051633430762, -0.345185782636792],
-        [0.0749010751157440, 0.180053080734478,  0.0749010751157440,
-         -0.345185782636792, -0.345185782636792, 1.36051633430762]
-    ])
+    H_inv = np.array(
+        [
+            [
+                1.87365927351160,
+                0.138559587411935,
+                0.138559587411935,
+                -0.638559587411936,
+                0.126340726488397,
+                -0.638559587411935,
+            ],
+            [
+                0.138559587411935,
+                1.87365927351160,
+                0.138559587411935,
+                -0.638559587411935,
+                -0.638559587411935,
+                0.126340726488397,
+            ],
+            [
+                0.138559587411935,
+                0.138559587411935,
+                1.87365927351160,
+                0.126340726488396,
+                -0.638559587411935,
+                -0.638559587411935,
+            ],
+            [
+                0.0749010751157440,
+                0.0749010751157440,
+                0.180053080734478,
+                1.36051633430762,
+                -0.345185782636792,
+                -0.345185782636792,
+            ],
+            [
+                0.180053080734478,
+                0.0749010751157440,
+                0.0749010751157440,
+                -0.345185782636792,
+                1.36051633430762,
+                -0.345185782636792,
+            ],
+            [
+                0.0749010751157440,
+                0.180053080734478,
+                0.0749010751157440,
+                -0.345185782636792,
+                -0.345185782636792,
+                1.36051633430762,
+            ],
+        ]
+    )
 
     return H_inv.dot(w)
 
@@ -638,7 +744,7 @@ def principal_coordinate(phi, x, y):
     """Determines the coordinates of the cartesian point *(x, y)* in the
     principal axis system given an axis rotation angle phi.
 
-    :param float phi: Prinicpal bending axis angle (degrees)
+    :param float phi: Principal bending axis angle (degrees)
     :param float x: x coordinate in the global axis
     :param float y: y coordinate in the global axis
     :return: Principal axis coordinates *(x1, y2)*
@@ -649,10 +755,9 @@ def principal_coordinate(phi, x, y):
     phi_rad = phi * np.pi / 180
 
     # form rotation matrix
-    R = np.array([
-        [np.cos(phi_rad), np.sin(phi_rad)],
-        [-np.sin(phi_rad), np.cos(phi_rad)]
-    ])
+    R = np.array(
+        [[np.cos(phi_rad), np.sin(phi_rad)], [-np.sin(phi_rad), np.cos(phi_rad)]]
+    )
 
     # calculate rotated x and y coordinates
     x_rotated = R.dot(np.array([x, y]))
@@ -664,7 +769,7 @@ def global_coordinate(phi, x11, y22):
     """Determines the global coordinates of the principal axis point *(x1, y2)* given principal
     axis rotation angle phi.
 
-    :param float phi: Prinicpal bending axis angle (degrees)
+    :param float phi: Principal bending axis angle (degrees)
     :param float x11: 11 coordinate in the principal axis
     :param float y22: 22 coordinate in the principal axis
     :return: Global axis coordinates *(x, y)*
@@ -675,10 +780,9 @@ def global_coordinate(phi, x11, y22):
     phi_rad = phi * np.pi / 180
 
     # form transposed rotation matrix
-    R = np.array([
-        [np.cos(phi_rad), -np.sin(phi_rad)],
-        [np.sin(phi_rad), np.cos(phi_rad)]
-    ])
+    R = np.array(
+        [[np.cos(phi_rad), -np.sin(phi_rad)], [np.sin(phi_rad), np.cos(phi_rad)]]
+    )
     # calculate rotated x_1 and y_2 coordinates
     x_rotated = R.dot(np.array([x11, y22]))
 
